/* Income from agriculture - Rabi crops */

data agri01; merge p91.f09b1 p91.f09b2 p91.f09b3; by hid cropcd;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
raink=r_lndrfa*8.; irrik=r_lndira*8.;
land=(sum(raink, r_lndrfk, irrik, r_lndrfk))/8.;

/*////////////////////////////////////////////////////////////////////
/  Convert all quantities into maunds (expenses are -ive amounts)    /
////////////////////////////////////////////////////////////////////*/
if  r_quanu eq 1. then quantity =        r_quan/40.;
if  r_quanu eq 2. then quantity =            r_quan;

if  r_gvquu eq 1. then landlord =   (r_gvqu/40)*-1.;
if  r_gvquu eq 2. then landlord =      (r_gvqu)*-1.;
if  r_gvpct gt 0.  and landlord eq . then landlord=(r_gvpct*quantity/100)*-1.;

if r_payexu eq 1. then   labour = (r_payexu/40)*-1.;
if r_payexu eq 2. then   labour =    (r_payexu)*-1.;

if  r_seedu eq 1. then     seed =   (r_seed/40)*-1.;
if  r_seedu eq 2. then     seed =      (r_seed)*-1.;

if r_gvothu eq 1. then    other =  (r_gvoth/40)*-1.;
if r_gvothu eq 2. then    other =     (r_gvoth)*-1.;

if r_lvstku eq 1. then    lvstk =  (r_lvstk/40)*-1.;
if r_lvstku eq 2. then    lvstk =     (r_lvstk)*-1.;

/*////////////////////////////////////////////////////////////////////
/  Convert all prices into Rs. per maund                             /
////////////////////////////////////////////////////////////////////*/
if r_buy1u eq 1. then price = r_buy1rs*40.;
if r_buy1u eq 2. then price =     r_buy1rs;

/*////////////////////////////////////////////////////////////////////
/  Ave. yield per acre and ave. price for crop by province           /
////////////////////////////////////////////////////////////////////*/
data yield; merge agri01 p91.weights; by hid;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
if quantity gt 0. and land gt 0. and price gt 0.;
yield=quantity/land;

proc means noprint mean;
var yield price;
weight weight;
class province cropcd;
output out=stats1 mean=aveyield aveprice;

data stats1; set stats1;
if province gt 0. and cropcd gt 0.;
keep cropcd province aveyield aveprice;
proc print;
title "Average yield and price for crop by province";

proc sort data=stats1; by province cropcd;
proc sort data=agri01; by province cropcd;

data agri01; merge agri01 stats1; by province cropcd;

/*////////////////////////////////////////////////////////////////////
/  Assigning quantity harvested to those who have reported           /
/  quantity harvested in acres or kanals.                            /
////////////////////////////////////////////////////////////////////*/
if r_quanu eq 6. then quantity = aveyield* r_quan;
if r_quanu eq 7. then quantity = aveyield* r_quan/8.;

qntcrop = sum(quantity, landlord, labour, seed, other, lvstk);
 qntexp = sum(landlord, labour, seed, other, lvstk);

/*////////////////////////////////////////////////////////////////////
/  Calculating value of crop                                         /
////////////////////////////////////////////////////////////////////*/
if qntcrop gt 0.  and   price gt 0. then valcrop = qntcrop*valcrop;
if qntcrop gt 0.  and valcrop eq  . then valcrop = qntcrop*aveprice;
if r_quanu eq 9. then valcrop  =  r_quan + (qntexp*price);

proc sort; by hid cropcd;
proc means noprint sum;
class hid;
var valcrop;
output out=x.agr_inc1 sum=valcrop1;

data x.agr_inc1; set x.agr_inc1;
if hid gt 0.;
keep hid valcrop1;
run;
