/* Income from agriculture - Kharif crops  */

data agri01; merge p91.f09b4 p91.f09b5 p91.f09b6; by hid cropcd;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
raink=k_lndrfa*8.; irrik=k_lndira*8.;
land=(sum(raink, k_lndrfk, irrik, k_lndrfk))/8.;

/*////////////////////////////////////////////////////////////////////
/  Convert all quantities into maunds (expenses are -ive amounts)    /
////////////////////////////////////////////////////////////////////*/
if  k_quanu eq 1. then quantity =        k_quan/40.;
if  k_quanu eq 2. then quantity =            k_quan;

if  k_gvquu eq 1. then landlord =   (k_gvqu/40)*-1.;
if  k_gvquu eq 2. then landlord =      (k_gvqu)*-1.;
if  k_gvpct gt 0.  and landlord eq . then landlord=(k_gvpct*quantity/100)*-1.;

if k_payexu eq 1. then   labour = (k_payexu/40)*-1.;
if k_payexu eq 2. then   labour =    (k_payexu)*-1.;

if  k_seedu eq 1. then     seed =   (k_seed/40)*-1.;
if  k_seedu eq 2. then     seed =      (k_seed)*-1.;

if k_gvothu eq 1. then    other =  (k_gvoth/40)*-1.;
if k_gvothu eq 2. then    other =     (k_gvoth)*-1.;

if k_lvstku eq 1. then    lvstk =  (k_lvstk/40)*-1.;
if k_lvstku eq 2. then    lvstk =     (k_lvstk)*-1.;

/*////////////////////////////////////////////////////////////////////
/  Convert all prices into Rs. per maund                             /
////////////////////////////////////////////////////////////////////*/
if k_buy1u eq 1. then price = k_buy1rs*40.;
if k_buy1u eq 2. then price =     k_buy1rs;

/*////////////////////////////////////////////////////////////////////
/  Ave. yield per acre and ave. price for crop by province           /
////////////////////////////////////////////////////////////////////*/
data yield; merge agri01 p91.weights; by hid;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
if quantity gt 0. and land gt 0. and price gt 0.;
yield=quantity/land;

proc means noprint mean;
var yield price;
weight weight;
class province cropcd;
output out=stats1 mean=aveyield aveprice;

data stats1; set stats1;
if province gt 0. and cropcd gt 0.;
keep cropcd province aveyield aveprice;
proc print;
title "Average yield and price for crop by province";

proc sort data=stats1; by province cropcd;
proc sort data=agri01; by province cropcd;

data agri01; merge agri01 stats1; by province cropcd;

/*////////////////////////////////////////////////////////////////////
/  Assigning quantity harvested to those who have reported           /
/  quantity harvested in acres or kanals.                            /
////////////////////////////////////////////////////////////////////*/
if k_quanu eq 6. then quantity = aveyield* k_quan;
if k_quanu eq 7. then quantity = aveyield* k_quan/8.;

qntcrop = sum(quantity, landlord, labour, seed, other, lvstk);
 qntexp = sum(landlord, labour, seed, other, lvstk);

/*////////////////////////////////////////////////////////////////////
/  Calculating value of crop                                         /
////////////////////////////////////////////////////////////////////*/
if qntcrop gt 0.  and   price gt 0. then valcrop = qntcrop*valcrop;
if qntcrop gt 0.  and valcrop eq  . then valcrop = qntcrop*aveprice;
if k_quanu eq 9. then valcrop  =  k_quan + (qntexp*price);

proc sort; by hid cropcd;
proc means noprint sum;
class hid;
var valcrop;
output out=x.agr_inc2 sum=valcrop2;

data x.agr_inc2; set x.agr_inc2;
if hid gt 0.;
keep hid valcrop2;
run;
