/* Produces a preliminary estimate of profits from family enterprise */

/*  get no. of weeks operated in the year from page 63.  */
data a; set p91.f10a2;
week=mosenop*4.; if mosenop eq 12. then week =52.;
keep hid entno week typent;

data o; set p91.f10a2;
indust=typent; keep hid entno indust;

/* Expenses for the enterprise */
proc sort data=a; by hid entno;
proc sort data=b; by hid entno;
data b; set p91.f10b;
data b; merge b a; by hid entno;
if week eq . then week = 52.;
expa=0; expb=0;
if vexpwk gt 0. then expa    = vexpwk*week;
if uexpyr eq 5. and vexpyr gt 0 and frexpyr gt 0 then expb=vexpyr*frexpyr*12.;
if uexpyr eq 6. and vexpyr gt 0 and frexpyr gt 0 then expb=vexpyr*frexpyr*4.;
if uexpyr eq 7. and vexpyr gt 0 and frexpyr gt 0 then expb=vexpyr*frexpyr*2.;
if uexpyr eq 8. and vexpyr gt 0 and frexpyr gt 0 then expb=vexpyr*frexpyr;

/*  assuming 20% consumed by household  */
if hhuse eq 1. then expa = expa*0.8;
if hhuse eq 1. then expb = expb*0.8;

if expa gt 0. then exp = expa;
if expb gt 0. then exp = expb;
 /* i.e. where available, normal expenses taken in preference to
    expenditures reported for last 7 days */

proc sort; by hid entno;

proc summary data=b;
class hid entno;
   var exp;
   output out=c sum= ;
data c; set c;
if hid gt 100000000.;
nitems = _freq_;
keep hid entno exp;

data d; set p91.f10d;
proc sort; by hid entno;

data d; merge d a; by hid entno;
cash = 0.; kind = 0.; contract = 0.; hconsump = 0.;
if week eq . then week = 52;

/* Again, revenues normally received taken in preference to
   those in past 14 days */
if (  cshsal gt 0. and  ucshsal eq 3.) then    cash =   cshsal*week*7.;
if (  cshsal gt 0. and  ucshsal eq 4.) then    cash =   cshsal*week;
if (  cshsal gt 0. and  ucshsal eq 5.) then    cash =   cshsal*week/4.;
if (  cshsal gt 0. and  ucshsal eq 6.) then    cash =   cshsal*4.;
if (  cshsal gt 0. and  ucshsal eq 7.) then    cash =   cshsal*2.;
if (  cshsal gt 0. and  ucshsal eq 8.) then    cash =   cshsal;

if (  kndsal gt 0. and  ukndsal eq 3.) then    kind =   kndsal*week*7.;
if (  kndsal gt 0. and  ukndsal eq 4.) then    kind =   kndsal*week;
if (  kndsal gt 0. and  ukndsal eq 5.) then    kind =   kndsal*week/4.;
if (  kndsal gt 0. and  ukndsal eq 6.) then    kind =   kndsal*4.;
if (  kndsal gt 0. and  ukndsal eq 7.) then    kind =   kndsal*2.;
if (  kndsal gt 0. and  ukndsal eq 8.) then    kind =   kndsal;

if ( vscntus gt 0. and  uscntus eq 3.) then contract = vscntus*week*7.;
if ( vscntus gt 0. and  uscntus eq 4.) then contract = vscntus*week;
if ( vscntus gt 0. and  uscntus eq 5.) then contract = vscntus*week/4.;
if ( vscntus gt 0. and  uscntus eq 6.) then contract = vscntus*4.;
if ( vscntus gt 0. and  uscntus eq 7.) then contract = vscntus*2.;
if ( vscntus gt 0. and  uscntus eq 8.) then contract = vscntus;

if (vhconsus gt 0. and uhconsus eq 3.) then hconsump = vhconsus*week*7.;
if (vhconsus gt 0. and uhconsus eq 4.) then hconsump = vhconsus*week;
if (vhconsus gt 0. and uhconsus eq 5.) then hconsump = vhconsus*week/4.;
if (vhconsus gt 0. and uhconsus eq 6.) then hconsump = vhconsus*4.;
if (vhconsus gt 0. and uhconsus eq 7.) then hconsump = vhconsus*2.;
if (vhconsus gt 0. and uhconsus eq 8.) then hconsump = vhconsus;

revenue = sum(of cash kind contract hconsump);
keep hid entno cash kind contract hconsump revenue cshrevlv kndrevlv
     vscontlv hconslv;

proc sort; by hid entno;

/* computes total value of assets in the enterprise   */
data e; set p91.f10c1;
if vbasst eq . then vbasst = 0.;
keep hid entno typent basstcd vbasst;

proc sort; by hid entno;
proc summary data=e;
class hid entno;
   var vbasst;
   output out=f sum= ;
data f; set f;
if hid gt 100000000.;
nasset = _freq_;
valasset = vbasst;
keep hid entno nasset valasset;


proc sort data=c; by hid entno;
proc sort data=d; by hid entno;
proc sort data=f; by hid entno;

data a; merge c d f o; by hid entno;
expense = exp;
data ent; set a;
vasset=valasset;
keep hid entno indust revenue expense vasset;
proc sort; by indust;

proc univariate noprint;
var revenue;
by indust;
output out=revenue mean=rev p5=pmin p95=pmax;
data revenue; set revenue; one=1; keep rev pmin pmax indust;
proc sort; by indust;
data ent; merge ent revenue; by indust;
if   revenue gt pmax then   revenue = pmax;

proc univariate noprint;
var expense;
by indust;
output out=expense mean=exp p5=pmin p95=pmax;
data expense; set expense; one=1; keep exp pmin pmax indust;
proc sort; by indust;

data ent; merge ent expense; by indust;
if   expense gt pmax then   expense = pmax;

if expense gt 0. and revenue gt 0 then profit = revenue - expense;
if expense eq  . and revenue gt 0 then profit = revenue;

data ent; set ent;
keep hid entno profit revenue expense vasset;
proc means;

proc means noprint sum;
var profit;
class hid;
output out=ent sum=profit;

data x.entprise; set ent;
if hid gt 0.;
keep hid profit;
proc means;
run;

