/*/////////////////////////////////////////////////////////////////
/  This program combines income figures from the various sections /
/  and produces an estimate of total household income.            /
/  Four sub-categories are also kept:                             /
/   (i) Income from agriculture                                   /
/  (ii) Income from non-farm self-employment                      /
/ (iii) Income from wage employment                               /
/  (iv) Other income                                              /
/  When calculating total household income, for those households  /
/  that report negative profits from family enterprise activities /
/  and for those that report negative incomes from agriculture    /
/  income from these activities is taken to be zero.              /
/////////////////////////////////////////////////////////////////*/

data  a1; set x.agrinput;
data  a2; set x.agrrent1;
data  a3; set x.agrrent2;
data  a4; set x.agr_inc1;
data  a5; set x.agr_inc2;
data  a6; set x.agr_inc3;
data  a7; set x.dairy;
data  a8; set x.labor;
data  a9; set x.lvstock;
data a10; set x.process;
data a11; set x.sug_cane;

data agri; merge a1 a2 a3 a4 a5 a6 a7 a8 a9 a10 a11; by hid;
agri_inc = sum(of agrinput agrrent1 agrrent2 valcrop1 valcrop2 valfruit
               dairy labor lvstock process valcane);

data entprise; set x.entprise;
entprise = profit; drop profit;

data w1; set x.w_agri;
data w2; set x.w_nagri;
data w3; set x.abroad;
data w4; set x.pension;
data w5; set x.timeuse;

data wage; merge w1 w2 w3 w4 w5; by hid pid;
wages = sum(of w_agri w_nagri pension abroad womeninc);
proc means noprint sum;
var wages;
class hid;
output out = wages sum = wages;

data wages; set wages;
if hid gt 0.;

data o1; set x.remitin;
data o2; set x.credit;
data o3; set x.housing;
data o4; set x.invments;
data o5; set x.otherinc;

data other; merge o1 o2 o3 o4 o5; by hid;
other = sum(of h_remit o_remit interest hrent invments otherinc);


data x.pihsinc; merge agri entprise wages other; by hid;
pos_agr = 0.;
pos_ent = 0.;
if agri_inc gt 0. then pos_agr = agri_inc;
if entprise gt 0. then pos_ent = entprise;
hhincome = sum(of pos_agr pos_ent wages other);
keep hid hhincome agri_inc entprise wages other;
proc means;
run;
