/* Expenditure related to casual and permanent hired labour */

/*////////////////////////////////////////////////////////////////////
/  Expenses related to hiring casual workers calculated as no. of    /
/  man-days times (cash + in-kind) payments per day, as well as      /
/  value of meals provided.                                          /
/  For permanent labor, expenses taken to be 10% of bonding payment  /
/  plus advance + balance of advance + in-kind payments.             /
////////////////////////////////////////////////////////////////////*/

data casual; set p91.f09g2;
if labpmtcu eq 3. or labpmtku eq 3.;
if labpmtc eq . then labpmtc = 0.;
if labpmtk eq . then labpmtk = 0.;
if labpmtcu eq 3. and labpmtku eq 3. then payment = labpmtc+labpmtk;
if labpmtcu eq 3. and  payment eq  . then payment = labpmtc;
if labpmtku eq 3. and  payment eq  . then payment = labpmtk;

/* 4 households report labor cash payments of over 100 per day, which */
/* appear to be typos.  Payment per day for these households taken to */
/* be 30 Rs. day, which is roughly the average reported by other hhs. */

if labpmtcu eq 3. and labpmtc gt 100. then payment = 30.+labpmtk;

meals = mealslab*cstmlab;
if meals eq . then meals = 0.;
amount = (labdays*payment)+meals;

data casual; set casual;
casual = amount;
if amount gt 0.;
keep hid casual;

proc means noprint sum;
var casual;
class hid;
output out=casual sum=casual;

data casual; set casual;
if casual gt 0. and casual ne .;
keep hid casual;


data plabor1; set p91.f09g3;
if permlab eq 1.;

/* Bonding payments */
if amtbnd gt 0. then bond = amtbnd/10.;
if amtbnd eq  . then bond = 0.;

/* Advance payments */
if amtadvp gt 0. then adv = amtadvp;
if amtadvp eq  . then adv = 0.;

if amtbalu eq 4. then balance = amtbal*52.;
if amtbalu eq 5. then balance = amtbal*12.;
if amtbalu eq 6. then balance = amtbal*4.;
if amtbalu eq 7. then balance = amtbal*2.;
if amtbalu eq 8. then balance = amtbal;
if balance eq . then balance = 0.;

advance = sum(of adv balance);

/* In-kind payments */
/*////////////////////////////////////////////////////////////////////
/   In order to assign values to in-kind payments, prices for the    /
/   commodities taken from agri. section (that received per maund    /
/   from primary buyer. (sugarcane = 15 Rs/maund. -see sug_cane.sas) /
////////////////////////////////////////////////////////////////////*/

data prices; merge p91.f09b1 p91.weights; by hid;     /* Rabi crops */
if (cropcd eq 11. or cropcd eq 15. or cropcd eq 31.) and r_buy1u eq 2.;
keep hid weight cropcd r_buy1rs;
proc means noprint mean;
class cropcd;
var r_buy1rs;
weight weight;
output out=prices1 mean=price;

data prices1; set prices1;
if cropcd gt 0.;
keep cropcd price;

data prices; merge p91.f09b4 p91.weights; by hid;     /* Kharif crops */
if (cropcd eq 1 or cropcd eq 2. or cropcd eq 13. or cropcd eq 21.)
      and k_buy1u eq 2.;
keep hid weight cropcd k_buy1rs;
proc means noprint mean;
class cropcd;
var k_buy1rs;
weight weight;
output out=prices2 mean=price;

data prices2; set prices2;
if cropcd gt 0.;
keep cropcd price;

data prices3;                                      /* Sugarcane */
price = 15.;
cropcd = 101.;

data prices3; set prices3;
if cropcd gt 0.;
keep cropcd price;

data prices; merge prices1 prices2 prices3; by cropcd;
keep cropcd price;
proc sort; by cropcd;


data inkind; set p91.f09g3;
if qcrpgiv1 gt 0. or qcrpgiv2 gt 0.;
keep hid crpgiv1 qcrpgiv1 ucrpgiv1 crpgiv2 qcrpgiv2 ucrpgiv2;

data inkind; set inkind;
cropcd = crpgiv1;
proc sort; by cropcd;

data inkind; merge inkind prices; by cropcd;
price1=price; drop price;

data inkind; set inkind;
cropcd = crpgiv2;
proc sort; by cropcd;

data inkind; merge inkind prices; by cropcd;
price2=price; drop price;


if ucrpgiv1 eq 1. then qnt1 = qcrpgiv1/40.;
if ucrpgiv1 eq 2. then qnt1 = qcrpgiv1;
if ucrpgiv2 eq 1. then qnt2 = qcrpgiv2/40.;
if ucrpgiv2 eq 2. then qnt2 = qcrpgiv2;

if ucrpgiv1 eq 9. then amt1 = qcrpgiv1;
if ucrpgiv2 eq 9. then amt2 = qcrpgiv2;

if amt1 eq . then amt1 = qnt1*price1;
if amt2 eq . then amt2 = qnt2*price2;

inkind = sum(of amt1 amt2);
proc sort; by hid;

data inkind; set inkind;
if inkind gt 0.;
keep hid inkind;


data plabor; merge plabor1 inkind; by hid;
if inkind eq . then inkind = 0.;
plabor = bond + advance + inkind;
if plabor gt 0.;

data labor; merge casual plabor; by hid;
if hid gt 0.;
if casual eq . then casual = 0.;
if plabor eq . then plabor = 0.;

if casual gt 0. then pmt1 = (casual)*-1.;
if plabor gt 0. then pmt2 = (plabor)*-1.;

labor = sum(of pmt1 pmt2);

data x.labor; set labor;
if labor lt 0. and labor ne .;
keep hid labor;
run;
