/* Wage income - agriculture  */

data agri; merge p91.f05a1 p91.f05a2; by hid pid;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
if agwrk12m eq 1.;

if vbondpmt ge 0 then bond_inc = vbondpmt/10.;
if adv12m ge 0 then advance  = adv12m;

/******* Somewhat arbitrary; income from bonding payment taken to be
         10% of value of bonding payment (i.e. r of 10% on loan)   ******/

if csh12m ge 0 and csh12mu eq 3. then cash_p = csh12m*dwrky_p;
if csh12m ge 0 and csh12mu eq 4. then cash_p = csh12m*52.;
if csh12m ge 0 and csh12mu eq 5. then cash_p = csh12m*12.;
if csh12m ge 0 and csh12mu eq 6. then cash_p = csh12m* 4.;
if csh12m ge 0 and csh12mu eq 7. then cash_p = csh12m* 2.;
if csh12m ge 0 and csh12mu eq 8. then cash_p = csh12m;

if rabid_s gt 0 or rabid_s gt 0. then days= sum(of rabid_s khard_s);
if pmtday_s gt 0 and days gt 0 then cash_s = pmtday_s*days;

/******* Different prices for the various commodities taken from agri.
         section.  Price taken to be that received per maund from
         primary buyer.  Price of "Other" assumed to be same as wheat.
         Price of gur taken from section 12A, code 318.               ******/

data prices1; merge p91.f09b1 p91.weights; by hid;     /* Wheat, tobacco */
if (cropcd eq 11. or cropcd eq 91.) and r_buy1u eq 2.;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
if cropcd eq 11. then code = 1.; if cropcd eq 91. then code = 5.;

keep hid province urbrural weight code r_buy1rs;
proc means noprint mean;
class province code;
var r_buy1rs;
weight weight;
output out=prices1 mean=price;

data prices1; set prices1;
if province gt 0. and code gt 0.;
keep province code price;

data prices2; merge p91.f09b4 p91.weights; by hid;     /* Cotton, rice, */
if (cropcd eq 01. or cropcd eq 12. or                  /* maize, fodder */
    cropcd eq 21. or cropcd eq 41.) and k_buy1u eq 2.;
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
if cropcd eq 01. then code = 4.; if cropcd eq 12. then code = 2.;
if cropcd eq 21. then code = 3.; if cropcd eq 41. then code = 7.;

keep hid province urbrural weight code k_buy1rs;
proc means noprint mean;
class province code;
var k_buy1rs;
weight weight;
output out=prices2 mean=price;

data prices2; set prices2;
if province gt 0. and code gt 0.;
keep province code price;

data prices3; merge p91.f12a p91.weights; by hid;     /* Gur */
if foodcd eq 318. and uq12alv eq 1.;      /* Price per kilo */
province=int(hid/100000000);
urbrural=(int(hid/10000000)-10*province);
code = 6.;
price = cst12alv * 40.;                   /* Convert to price per maund */

proc means noprint mean;
class province code;
var price;
weight weight;
output out=prices3 mean=price;

data prices3; set prices3;
if province gt 0. and code gt 0.;
keep province code price;

data prices4; set prices1;     /* Price of Other taken to be same as wheat */
if code eq 1.;
code = 10.;

data prices; set prices1 prices2 prices3 prices4;
proc sort; by province code;

proc datasets;
delete prices1 prices2 prices3 prices4;

data inkind1; set agri;
if inkcd_p1 gt 0.;
code = inkcd_p1; quant = inkn_p1; unit = inku_p1;
if unit eq 3. then value1 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value1;
proc sort; by province code;
data inkind1; merge inkind1 prices; by province code;
if value1 le 0. then value1 = quant * price;
keep hid pid value1;
proc sort; by hid pid;

data inkind2; set agri;
if inkcd_p2 gt 0.;
code = inkcd_p2; quant = inkn_p2; unit = inku_p2;
if unit eq 3. then value2 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value2;
proc sort; by province code;
data inkind2; merge inkind2 prices; by province code;
if value2 le 0. then value2 = quant * price;
keep hid pid value2;
proc sort; by hid pid;

data inkind3; set agri;
if inkcd_p3 gt 0.;
code = inkcd_p3; quant = inkn_p3; unit = inku_p3;
if unit eq 3. then value3 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value3;
proc sort; by province code;
data inkind3; merge inkind3 prices; by province code;
if value3 le 0. then value3 = quant * price;
keep hid pid value3;
proc sort; by hid pid;

data inkind4; set agri;
if inkcd_s1 gt 0.;
code = inkcd_s1; quant = inkn_s1; unit = inku_s1;
if unit eq 3. then value4 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value4;
proc sort; by province code;
data inkind4; merge inkind4 prices; by province code;
if value4 le 0. then value4 = quant * price;
keep hid pid value4;
proc sort; by hid pid;

data inkind5; set agri;
if inkcd_s2 gt 0.;
code = inkcd_s2; quant = inkn_s2; unit = inku_s2;
if unit eq 3. then value5 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value5;
proc sort; by province code;
data inkind5; merge inkind5 prices; by province code;
if value5 le 0. then value5 = quant * price;
keep hid pid value5;
proc sort; by hid pid;

data inkind6; set agri;
if inkcd_s3 gt 0.;
code = inkcd_s3; quant = inkn_s3; unit = inku_s3;
if unit eq 3. then value6 = quant;
if unit eq 1. then quant = quant / 40.;
keep hid pid province code quant unit value6;
proc sort; by province code;
data inkind6; merge inkind6 prices; by province code;
if value6 le 0. then value6 = quant * price;
keep hid pid value6;
proc sort; by hid pid;

data inkind; merge inkind1 inkind2 inkind3 inkind4 inkind5 inkind6; by hid pid;
value = sum(of value1 value2 value3 value4 value5 value6);
if value gt 0.;

data x.w_agri; merge agri inkind; by hid pid;
w_agri = sum (of cash_p cash_s advance bond_inc value);
if w_agri gt 0.;
keep hid pid w_agri;
run;
